
# Slot: default_value


Optional default value for variable-valued attributes.

URI: [nwb_schema_language:default_value](https://w3id.org/p2p_ld/nwb-schema-language/default_value)


## Domain and Range

None &#8594;  <sub>0..1</sub> [AnyType](AnyType.md)

## Parents


## Children


## Used by

 * [Attribute](Attribute.md)
 * [Dataset](Dataset.md)
